import os
import sys
from pathlib import Path

from pyrootutils import setup_root

# this line finds the absolute path of the original python script that is being run
startfile = os.path.abspath(sys.argv[0])

# if we are in notebook or pytest, just use current working directory
if startfile.endswith("ipykernel_launcher.py") or startfile.endswith("pytest"):
    startfile = os.getcwd()

# convert to Path object
startfile = Path(startfile)

# this line recursively searches for ".project-root" file
# starting from folder containing the entry python script and going up until it finds it
root = setup_root(
    search_from=startfile,
    indicator=".project-root",
    project_root_env_var=True,
    dotenv=True,
    pythonpath=True,
    cwd=False,
)



from setuptools import find_packages, setup

setup(
    name="autoroot",
    version="1.0.0",
    license="MIT",
    description="Simple package for easy project root setup",
    long_description="",
    long_description_content_type="text/markdown",
    url="https://github.com/ashleve/autoroot",
    author="Łukasz Zalewski",
    author_email="lukasz.zalewski.ai@gmail.com",
    packages=find_packages(),
    python_requires=">=3.7.0",
    include_package_data=True,
    install_requires=["python-dotenv>=0.20.0", "pyrootutils>=1.0.4"],
    tests_require=["pytest"],
)
